@@ -1032,6 +1032,13 @@
 ((Songti\ TC Bold) ((Songti.ttc 2 66899384)))
 ((Songti\ TC Light) ((Songti.ttc 5 66899384)))
 ((Songti\ TC Regular) ((Songti.ttc 7 66899384)))
+((Source\ Han\ Sans\ SC Regular) ((SourceHanSansSC-Regular.otf 0 16412776)))
+((Source\ Han\ Sans\ SC Bold) ((SourceHanSansSC-Bold.otf 0 16983696)))
+((Source\ Han\ Sans\ SC Heavy) ((SourceHanSansSC-Heavy.otf 0 17324776)))
+((Source\ Han\ Sans\ SC Medium) ((SourceHanSansSC-Medium.otf 0 16490072)))
+((Source\ Han\ Sans\ SC Normal) ((SourceHanSansSC-Normal.otf 0 16353464)))
+((Source\ Han\ Sans\ SC Light) ((SourceHanSansSC-Light.otf 0 16229588)))
+((Source\ Han\ Sans\ SC ExtraLight) ((SourceHanSansSC-ExtraLight.otf 0 15140064)))
 ((STFangsong Regular) ((华文仿宋.ttf 0 15734488) (华文仿宋.ttf 0 15884236) (华文仿宋.ttf 0 15884824)))
 ((STHeiti Light) ((华文细黑.ttf 0 17140620) (华文细黑.ttf 0 15642136) (华文细黑.ttf 0 15692256)))
 ((STHeiti Regular) ((华文黑体.ttf 0 13631224) (华文黑体.ttf 0 13631780)))
@@ -1134,7 +1141,7 @@
 ((TeX\ Gyre\ Pagella Bold\ Italic) ((texgyrepagella-bolditalic.otf 0 134516)))
 ((TeX\ Gyre\ Pagella Italic) ((texgyrepagella-italic.otf 0 146432)))
 ((TeX\ Gyre\ Pagella Regular) ((texgyrepagella-regular.otf 0 144472)))
-((TeX\ Gyre\ Pagella\ Math Regular) ((texgyrepagella-math.otf 0 600760)))
+((TeX\ Gyre\ Pagella\ Math Regular) ((texgyrepagella-math.otf 0 601220)))
 ((TeX\ Gyre\ Schola Bold) ((texgyreschola-bold.otf 0 141752)))
 ((TeX\ Gyre\ Schola Bold\ Italic) ((texgyreschola-bolditalic.otf 0 144864)))
 ((TeX\ Gyre\ Schola Italic) ((texgyreschola-italic.otf 0 143152)))
@@ -1144,7 +1151,7 @@
 ((TeX\ Gyre\ Termes Bold\ Italic) ((texgyretermes-bolditalic.otf 0 144180)))
 ((TeX\ Gyre\ Termes Italic) ((texgyretermes-italic.otf 0 141324)))
 ((TeX\ Gyre\ Termes Regular) ((texgyretermes-regular.otf 0 140932)))
-((TeX\ Gyre\ Termes\ Math Regular) ((texgyretermes-math.otf 0 532244)))
+((TeX\ Gyre\ Termes\ Math Regular) ((texgyretermes-math.otf 0 532404)))
 ((TeX\ Hershey Regular) ((hscs10.tfm 0 0)))
 ((TeX\ Linear\ B) ((linb10.tfm 0 972)))
 ((TeX\ Ogham) ((ogham10.tfm 0 360)))
