@@ -1,4 +1,9 @@
 (Al\ Bayan Al\ Bayan)
+(Al\ Bayan\ PUA Al\ Bayan\ PUA)
+(Al\ Nile Al\ Nile)
+(Al\ Nile\ PUA Al\ Nile\ PUA)
+(Al\ Tarikh Al\ Tarikh)
+(Al\ Tarikh\ PUA Al\ Tarikh\ PUA)
 (Alex\ Toth Alex\ Toth Bold SansSerif Marker Comic Handwritten)
 (Alpenkreuzer Alpenkreuzer Black SansSerif Title)
 (American\ Typewriter American\ Typewriter Typewriter Proportional)
@@ -7,8 +12,11 @@
 (Apex\ Lake Apex\ Lake Bold Initials)
 (Apple\ Braille Apple\ Braille)
 (Apple\ Chancery Apple\ Chancery Calligraphic)
+(Apple\ Color\ Emoji Apple\ Color\ Emoji)
 (Apple\ LiGothic Apple\ LiGothic SansSerif)
 (Apple\ LiSung Apple\ LiSung)
+(Apple\ SD\ Gothic\ Neo Apple\ SD\ Gothic\ Neo SansSerif)
+(Apple\ SD\ Gothic\ NeoI Apple\ SD\ Gothic\ NeoI SansSerif)
 (Apple\ Symbols Apple\ Symbols SansSerif)
 (AppleGothic AppleGothic SansSerif)
 (Aqua\ Kana Aqua\ Kana SansSerif)
@@ -20,23 +28,33 @@
 (AR\ PL\ ZenKai\ Uni AR\ PL\ ZenKai\ Uni)
 (Architext Architext wide SmallCaps SansSerif)
 (Arial Arial SansSerif)
-(Arial\ Black Arial Black SansSerif)
 (Arial\ Hebrew Arial\ Hebrew SansSerif)
-(Arial\ Narrow Arial Condensed SansSerif)
-(Arial\ Rounded\ MT\ Bold Arial\ Rounded\ MT SansSerif)
+(Arial\ Hebrew\ Desk\ Interface Arial\ Hebrew\ Desk\ Interface SansSerif)
+(Arial\ Hebrew\ Scholar Arial\ Hebrew\ Scholar SansSerif)
+(Arial\ Rounded\ MT Arial\ Rounded\ MT SansSerif)
 (Arial\ Unicode\ MS Arial\ Unicode\ MS SansSerif)
 (Asana\ Math Asana\ Math)
 (Astroneo Astroneo Black Wide SciFi)
+(Athelas Athelas)
 (Aurulent\ Sans Aurulent SansSerif)
 (Aurulent\ Sans\ Mono Aurulent Mono SansSerif)
+(Avenir Avenir SansSerif)
+(Avenir\ Book Avenir\ Book SansSerif)
+(Avenir\ Next Avenir\ Next SansSerif)
 (Avocado Avocado italic ArtPen)
 (Ayuthaya Ayuthaya Mono SansSerif)
 (Baekmuk\ Gulim Baekmuk\ Gulim SansSerif)
 (Baghdad Baghdad)
+(Baghdad\ PUA Baghdad\ PUA)
 (Balham Balham SansSerif)
+(Bangla\ MN Bangla\ MN)
+(Bangla\ Sangam\ MN Bangla\ Sangam\ MN SansSerif)
+(Baoli\ SC Baoli\ SC)
 (Baskerville Baskerville)
 (Batang Batang)
 (BB\ Petie\ Boy BB\ Petie\ Boy)
+(Beirut Beirut)
+(Beirut\ PUA Beirut\ PUA)
 (Beroga Beroga Black Oblique SansSerif)
 (BiauKai BiauKai)
 (Big\ Caslon Big\ Caslon)
@@ -49,23 +67,29 @@
 (BloomingGroveAltBold BloomingGroveAlt Bold SansSerif)
 (BloomingGroveAlternate BloomingGroveAlternate SansSerif)
 (BloomingGroveBold BloomingGrove Bold SansSerif)
+(Bodoni\ 72 Bodoni\ 72)
+(Bodoni\ 72\ Oldstyle Bodoni\ 72\ Oldstyle Retro)
+(Bodoni\ 72\ Smallcaps Bodoni\ 72\ Smallcaps SmallCaps)
+(Bodoni\ Ornaments Bodoni\ Ornaments)
 (BPreplay BPreplay SansSerif)
+(Bradley\ Hand Bradley\ Hand Pen Handwritten)
 (Brewsky Brewsky Condensed Distorted Outline)
 (Brush\ Script\ MT Brush\ MT ArtPen Attached Handwritten)
 (Cake\ Frosting Cake\ Frosting Pen Decorative)
 (Casa\ Sans Casa SansSerif Wide)
 (Catenary\ Stamp Catenary\ Stamp Bold Retro)
-(Chalkboard Chalkboard SansSerif)
+(Chalkboard Chalkboard SansSerif Marker Handwritten)
+(Chalkboard\ SE Chalkboard\ SE SansSerif Marker Handwritten)
 (Chalkduster Chalkduster SansSerif Chalk Handwritten)
 (Charakterny Charakterny Italic Miscellaneous)
 (Charis\ SIL Charis\ SIL)
+(Charter Charter)
 (Chartrand Chartrand)
 (Chronicles\ of\ Arkmar Chronicles\ of\ Arkmar Condensed Pen Decorative Distorted Gothic)
 (CMU\ Bright CMU\ Bright SansSerif)
 (CMU\ Classical\ Serif CMU\ Classical)
 (CMU\ Concrete CMU\ Concrete)
 (CMU\ Sans\ Serif CMU SansSerif)
-(CMU\ Sans\ Serif\ Demi\ Condensed CMU SansSerif DemiCondensed)
 (CMU\ Serif CMU)
 (CMU\ Serif\ Extra CMU\ Extra)
 (CMU\ Serif\ Upright\ Italic CMU\ Upright\ Italic)
@@ -73,37 +97,47 @@
 (CMU\ Typewriter\ Text\ Variable\ Width CMU Typewriter Proportional)
 (Cochin Cochin)
 (Comfortaa Comfortaa SansSerif)
-(Comic\ Sans\ MS Comic\ MS SansSerif Comic)
+(Comic\ Sans\ MS Comic\ MS SansSerif Comic Marker Handwritten)
 (Constanze Constanze ArtPen Calligraphic)
 (Copperplate Copperplate SmallCaps)
 (Corsiva\ Hebrew Corsiva\ Hebrew Italic)
 (Courier\ New Courier\ New Mono)
 (Cuprum Cuprum Condensed SansSerif)
 (Cyen Cyen Proportional Typewriter)
+(Damascus Damascus)
+(Damascus\ PUA Damascus\ PUA)
 (Dark\ Garden Dark\ Garden Condensed SmallCaps Pen Decorative Distorted)
 (DecoType\ Naskh DecoType\ Naskh)
+(DecoType\ Naskh\ PUA DecoType\ Naskh\ PUA)
 (DejaVu\ Sans DejaVu SansSerif)
-(DejaVu\ Sans\ Condensed DejaVu SansSerif Condensed)
-(DejaVu\ Sans\ Light DejaVu SansSerif)
 (DejaVu\ Sans\ Mono DejaVu Mono SansSerif)
 (DejaVu\ Serif DejaVu)
-(DejaVu\ Serif\ Condensed DejaVu Condensed)
 (Delius Delius SansSerif)
 (Delius\ Swash\ Caps Delius\ Swash\ Caps SansSerif)
 (Delius\ Unicase Delius\ Unicase SansSerif)
 (Denise Denise Condensed Italic SansSerif Pen Attached Handwritten)
 (Designer\ Notes Designer\ Notes Pen Handwritten)
 (Devanagari\ MT Devanagari\ MT)
+(Devanagari\ Sangam\ MN Devanagari\ Sangam\ MN SansSerif)
 (Didot Didot)
+(Din Din Condensed SansSerif)
+(DIN\ Alternate DIN\ Alternate SansSerif)
 (Dinosaur\ Skin Dinosaur\ Skin Decorative)
+(Diwan\ Kufi Diwan\ Kufi)
+(Diwan\ Kufi\ PUA Diwan\ Kufi\ PUA)
+(Diwan\ Thuluth Diwan\ Thuluth)
+(Doris\ PP Doris\ PP Bold SansSerif)
 (Double\ Strike Double\ Strike Light Pen Handwritten Outline)
 (Doulos\ SIL Doulos\ SIL)
 (Droid\ Sans Droid SansSerif)
 (Droid\ Sans\ Mono Droid Mono SansSerif)
 (Droid\ Serif Droid)
 (DuCahier\ xp DuCahier\ xp Wide Italic Pen Attached Handwritten)
+(Dufay Dufay)
 (Dustismo Dustismo SansSerif)
 (Dustismo\ Roman Dustismo\ Roman)
+(EB\ Garamond\ 12 EB\ Garamond\ 12)
+(EB\ Garamond\ Initials EB\ Garamond\ Initials)
 (Elvifrance Elvifrance Black Condensed SansSerif Caps Marker Comic)
 (Essays1743 Essays1743 Retro)
 (Estrangelo\ Edessa Estrangelo\ Edessa)
@@ -114,6 +148,9 @@
 (FandolKai FandolKai)
 (FandolSong FandolSong)
 (FangSong_GB2312 FangSong_GB2312 Mono)
+(Farah Farah)
+(Farah\ PUA Farah\ PUA)
+(Farisi Farisi)
 (Fava Fava Black SansSerif)
 (Foglihten Foglihten)
 (FoglihtenBlackPcs FoglihtenPcs Black Wide Caps)
@@ -125,7 +162,7 @@
 (FoglihtenNo04 FoglihtenNo04 Miscellaneous)
 (FoglihtenNo06 FoglihtenNo06 Caps)
 (FoglihtenPCS FoglihtenPCS SmallCaps)
-(Franklin\ Gothic\ Medium Franklin\ Gothic SansSerif)
+(Franklin\ Gothic Franklin\ Gothic SansSerif)
 (FreeMono Free Mono)
 (FreeSans Free SansSerif)
 (FreeSerif Free)
@@ -140,6 +177,8 @@
 (Gautami Gautami SansSerif)
 (Gears\ of\ Peace Gears\ of\ Peace Black Condensed SansSerif SciFi)
 (Geeza\ Pro Geeza\ Pro)
+(Geeza\ Pro\ Interface Geeza\ Pro\ Interface)
+(Geeza\ PUA Geeza\ PUA)
 (Gentium Gentium)
 (Gentium\ Basic Gentium\ Basic)
 (Gentium\ Book\ Basic Gentium\ Book\ Basic)
@@ -154,15 +193,31 @@
 (Goudy\ Bookletter\ 1911 Goudy\ Bookletter\ 1911)
 (Grunge\ Handwriting Grunge\ Handwriting Marker Handwritten)
 (Gujarati\ MT Gujarati\ MT)
+(Gujarati\ Sangam\ MN Gujarati\ Sangam\ MN SansSerif)
+(Gurmukhi\ MN Gurmukhi\ MN)
 (Gurmukhi\ MT Gurmukhi\ MT)
+(Gurmukhi\ Sangam\ MN Gurmukhi\ Sangam\ MN SansSerif)
 (Hairline\ Quadrata Hairline\ Quadrata Light Condensed Pen Gothic Handwritten Medieval)
 (Hand\ Drawn\ Shapes Hand\ Drawn\ Shapes Bold SansSerif Distorted)
 (Handserif Handserif Oblique SansSerif Retro)
+(Hannotate\ SC Hannotate\ SC SansSerif)
+(Hannotate\ TC Hannotate\ TC SansSerif)
+(HanziPen\ SC Hanzi\ SC Pen Handwritten)
+(HanziPen\ TC Hanzi\ TC Pen Handwritten)
 (HeadLineA HeadLineA SansSerif Title)
 (Hei Hei SansSerif)
 (Heiti\ SC Heiti\ SC SansSerif)
 (Heiti\ TC Heiti\ TC SansSerif)
+(HeitiUI\ GB18030PUA HeitiUI\ GB18030PUA SansSerif)
+(HeitiUI\ J HeitiUI\ J SansSerif)
+(HeitiUI\ K HeitiUI\ K SansSerif)
+(HeitiUI\ SC HeitiUI\ SC SansSerif)
+(HeitiUI\ TC HeitiUI\ TC SansSerif)
+(Helvetica Helvetica Light SansSerif)
+(Helvetica\ Neue Helvetica\ Neue SansSerif)
+(Helvetica\ Neue\ DeskInterface Helvetica\ Neue\ DeskInterface SansSerif)
 (Herculanum Herculanum Ancient)
+(Hiragino\ Kaku\ Gothic\ Interface Hiragino\ Kaku\ Gothic\ Interface SansSerif)
 (Hiragino\ Kaku\ Gothic\ Pro Hiragino\ Kaku\ Gothic\ Pro SansSerif)
 (Hiragino\ Kaku\ Gothic\ ProN Hiragino\ Kaku\ Gothic\ ProN SansSerif)
 (Hiragino\ Kaku\ Gothic\ Std Hiragino\ Kaku\ Gothic\ Std SansSerif)
@@ -171,10 +226,13 @@
 (Hiragino\ Maru\ Gothic\ ProN Hiragino\ Maru\ Gothic\ ProN SansSerif)
 (Hiragino\ Mincho\ Pro Hiragino\ Mincho\ Pro)
 (Hiragino\ Mincho\ ProN Hiragino\ Mincho\ ProN)
+(Hiragino\ Sans Hiragino SansSerif)
 (Hiragino\ Sans\ GB Hiragino\ GB SansSerif)
+(Hiragino\ Sans\ GB\ Interface Hiragino\ GB\ Interface SansSerif)
 (Hoefler\ Text Hoefler\ Text)
 (Impact Impact SansSerif Title)
 (InaiMathi InaiMathi SansSerif)
+(Iowan\ Old\ Style Iowan\ Old\ Style)
 (IPAGothic IPAGothic Bold SansSerif)
 (IPAMincho IPAMincho)
 (IPAPGothic IPAPGothic SansSerif)
@@ -183,6 +241,8 @@
 (Isabella Isabella Condensed Gothic Medieval)
 (ISL_Andvari ISL_Andvari Bold SansSerif SciFi)
 (ISL_Jupiter ISL_Jupiter SansSerif SciFi)
+(ITF\ Devanagari ITF\ Devanagari)
+(ITF\ Devanagari\ Marathi ITF\ Devanagari\ Marathi)
 (Itsadzoke Itsadzoke Bold Caps)
 (ItsadzokeS01 ItsadzokeS01 Caps TripleStroke)
 (ItsadzokeS02 ItsadzokeS02 Caps TripleStroke)
@@ -192,37 +252,53 @@
 (KacstOne KacstOne)
 (Kai Kai)
 (Kailasa Kailasa)
+(Kaiti\ SC Kaiti\ SC)
+(Kaiti\ TC Kaiti\ TC)
 (KaiTi_GB2312 KaiTi_GB2312 Mono)
+(Kannada\ MN Kannada\ MN)
+(Kannada\ Sangam\ MN Kannada\ Sangam\ MN SansSerif)
 (Kartika Kartika SansSerif)
 (Kawoszeh Kawoszeh)
 (Kedage Kedage)
+(Kefa Kefa)
 (Keyboard Keyboard)
 (Keytin Keytin Condensed SansSerif)
+(Khmer\ MN Khmer\ MN)
 (Khmer\ OS Khmer\ OS SansSerif)
 (Khmer\ OS\ System Khmer\ OS\ System SansSerif)
+(Khmer\ Sangam\ MN Khmer\ Sangam\ MN SansSerif)
 (Kinnari Kinnari)
+(Klee Klee SansSerif Marker)
 (Kochi\ Gothic Kochi\ Gothic Mono SansSerif)
+(Kohinoor\ Bangla Kohinoor\ Bangla SansSerif)
+(Kohinoor\ Devanagari Kohinoor\ Devanagari SansSerif)
+(Kohinoor\ Telugu Kohinoor\ Telugu)
+(Kohinoor\ Telugu\ Semibold Kohinoor\ Telugu\ SemiBold)
 (Kokonor Kokonor)
 (Krungthep Krungthep Bold Typewriter Proportional SansSerif)
 (KufiStandardGK KufiStandardGK)
+(KufiStandardGK\ PUA KufiStandardGK\ PUA)
 (Lampoon Lampoon Black Condensed SciFi)
+(Lantinghei\ SC Lantinghei\ SC SansSerif)
+(Lantinghei\ TC Lantinghei\ TC SansSerif)
+(Lao\ MN Lao\ MN)
+(Lao\ Sangam\ MN Lao\ Sangam\ MN SansSerif)
 (LastResort LastResort)
 (Latha Latha SansSerif)
-(Latin\ Modern\ Math Latin\ Modern\ Math)
-(Latin\ Modern\ Roman Latin\ Modern\ Roman)
 (Lato Lato SansSerif)
 (Liberation\ Mono Liberation Mono)
 (Liberation\ Sans Liberation SansSerif)
 (Liberation\ Serif Liberation)
+(Libian\ SC Libian\ SC Calligraphic)
 (LiHei\ Pro LiHei\ Pro SansSerif)
 (Lilith Lilith Condensed Caps SansSerif SciFi)
-(Linesquare\ Rounded\ Extended Linesquare\ Rounded\ Extended SansSerif Digital)
-(Linux\ Biolinum Linux\ Biolinum)
-(Linux\ Biolinum\ Capitals Linux\ Biolinum SmallCaps)
-(Linux\ Biolinum\ Keyboard Linux\ Biolinum Bold Wide Outline)
-(Linux\ Biolinum\ Outline Linux\ Biolinum\ Outline Outline)
-(Linux\ Biolinum\ Shadow Linux\ Biolinum\ Shadow Outline)
-(Linux\ Biolinum\ Slanted Linux\ Biolinum\ Slanted Oblique)
+(Linesquare\ Rounded Linesquare\ Rounded SansSerif Digital)
+(Linux\ Biolinum Linux\ Biolinum SansSerif)
+(Linux\ Biolinum\ Capitals Linux\ Biolinum SmallCaps SansSerif)
+(Linux\ Biolinum\ Keyboard Linux\ Biolinum Bold Wide SansSerif Outline)
+(Linux\ Biolinum\ Outline Linux\ Biolinum\ Outline SansSerif Outline)
+(Linux\ Biolinum\ Shadow Linux\ Biolinum\ Shadow SansSerif Outline)
+(Linux\ Biolinum\ Slanted Linux\ Biolinum\ Slanted Oblique SansSerif)
 (Linux\ Libertine Linux\ Libertine)
 (Linux\ Libertine\ Capitals Linux\ Libertine SmallCaps)
 (Linux\ Libertine\ Display Linux\ Libertine\ Display)
@@ -244,15 +320,20 @@
 (Lucida\ Grande Lucida\ Grande SansSerif)
 (Lucida\ Sans Lucida SansSerif)
 (Lucida\ Sans\ Unicode Lucida\ Unicode SansSerif)
+(Luminari Luminari Retro Decorative)
 (Luxi\ Mono Luxi Mono)
 (Luxi\ Sans Luxi SansSerif)
 (Luxi\ Serif Luxi)
 (Maassslicer Maassslicer Black Oblique SansSerif)
 (Making\ a\ List\ Checking\ it\ Twice Making\ a\ List\ Checking\ it\ Twice Light Pen Handwritten)
+(Malayalam\ MN Malayalam\ MN)
+(Malayalam\ Sangam\ MN Malayalam\ Sangam\ MN SansSerif)
 (Mallige Mallige)
 (Mangal Mangal SansSerif)
+(Marion Marion)
 (Marker\ Felt Marker\ Felt Marker Handwritten)
 (Marlett Marlett)
+(MarVoSym MarVoSym)
 (Meera Meera SansSerif)
 (Menlo Menlo Mono SansSerif)
 (Meyne\ Textur Meyne\ Textur Condensed Gothic Medieval)
@@ -260,34 +341,58 @@
 (Mikodacs Mikodacs Black Condensed SansSerif)
 (MikodacsPCS MikodacsPCS Black SmallCaps SansSerif)
 (MingLiU MingLiU Mono)
+(Mishafi Mishafi)
+(Mishafi\ Gold Mishafi\ Gold)
 (Monteiro\ Lobato Monteiro\ Lobato Retro)
 (MPH\ 2B\ Damase MPH\ 2B\ Damase)
 (MS\ Gothic MS\ Gothic SansSerif)
 (MS\ Mincho MS\ Mincho)
 (Mshtakan Mshtakan)
-(Mukti\ Narrow Mukti Condensed SansSerif)
+(Mukti Mukti SansSerif)
+(Muna Muna)
+(Muna\ PUA Muna\ PUA)
 (MV\ Boli MV\ Boli)
+(Myanmar\ MN Myanmar\ MN)
+(Myanmar\ Sangam\ MN Myanmar\ Sangam\ MN SansSerif)
 (Nadeem Nadeem)
+(Nadeem\ PUA Nadeem\ PUA)
+(Nanum\ Brush\ Script Nanum\ Brush\ Script Pen Handwritten)
+(Nanum\ Pen\ Script Nanum\ Script Pen Handwritten)
+(NanumGothic NanumGothic SansSerif)
+(NanumMyeongjo NanumMyeongjo)
 (New\ Peninim\ MT New\ Peninim\ MT)
 (Ninoshandwriting Ninoshandwriting Condensed SansSerif Pen Handwritten)
 (Norasi Norasi)
+(Noteworthy Noteworthy Marker Handwritten)
 (NTS\ Akkhara NTS\ Akkhara SansSerif)
 (Odstemplik Odstemplik Italic Attached Calligraphic)
 (Oldprint Oldprint Gothic Medieval)
+(OMGWilliamsSerifs OMGWilliamss Light)
+(OMGWriteLikeWilliam OMGWriteLikeWilliam SansSerif)
+(Open\ Sans Open SansSerif)
+(Open\ Sans\ Extrabold Open\ ExtraBold SansSerif Black)
+(Open\ Sans\ Semibold Open\ SemiBold SansSerif Bold)
 (OpenSymbol OpenSymbol)
-(Optima Optima)
+(Optima Optima SansSerif)
+(Oriya\ MN Oriya\ MN)
+(Oriya\ Sangam\ MN Oriya\ Sangam\ MN SansSerif)
 (Osaka Osaka Mono SansSerif)
 (Overhaul Overhaul Retro)
 (OxfordCP OxfordCP Attached Outline)
 (Pacifico Pacifico Bold Italic Pen Attached Handwritten)
+(Palatino Palatino)
 (Palatino\ Linotype Palatino\ Linotype)
 (Paper\ Cuts\ 2 Paper\ Cuts\ 2 Bold SansSerif Distorted)
-(Papyrus Papyrus Ancient)
+(Papyrus Papyrus Ancient SansSerif)
 (PCMyungjo PCMyungjo)
 (Penguin\ Attack Penguin\ Attack Decorative)
 (Perfect\ Dark\ Zero Perfect\ Dark\ Zero Condensed SciFi)
 (Phetsarath\ OT Phetsarath\ OT SansSerif)
+(Phosphate Phosphate Outline)
 (PilGi PilGi Pen Italic Attached Handwritten)
+(PingFang\ HK PingFang\ HK SansSerif)
+(PingFang\ SC PingFang\ SC SansSerif)
+(PingFang\ TC PingFang\ TC SansSerif)
 (PipeSquare\ Rounded PipeSquare\ Rounded Wide Miscellaneous)
 (Plantagenet\ Cherokee Plantagenet\ Cherokee)
 (Pointfree Pointfree Mono SansSerif)
@@ -298,14 +403,12 @@
 (Prociono Prociono)
 (Promocyja Promocyja Wide Oblique ArtPen Calligraphic)
 (Psicopatologia\ de\ la\ Vida\ Cotidiana Psicopatologia\ de\ la\ Vida\ Cotidiana Retro)
+(PT\ Mono PT Mono)
 (PT\ Sans PT SansSerif)
-(PT\ Sans\ Caption PT\ Caption SansSerif)
-(PT\ Sans\ Narrow PT SansSerif Condensed)
 (PT\ Serif PT)
-(PT\ Serif\ Caption PT\ Caption)
 (Purisa Purisa Pen Handwritten)
+(Quadrata\ Preciosa Quadrata\ Preciosa Gothic Medieval)
 (Quadrata\ preciosa Quadrata\ preciosa Condensed Gothic Medieval)
-(Quadrata\ Preciosa\ Extended Quadrata\ Preciosa\ Extended Oblique Gothic Medieval)
 (QumpellkaNo12 QumpellkaNo12 Italic)
 (Raanana Raanana)
 (Raavi Raavi SansSerif)
@@ -320,24 +423,42 @@
 (Reswysokr Reswysokr Condensed SansSerif)
 (Ringling Ringling Black Miscellaneous)
 (Saab Saab)
+(Sana Sana)
+(Sana\ PUA Sana\ PUA)
 (Sathu Sathu SansSerif)
+(Savoye\ LET Savoye\ LET ArtPen Handwritten)
+(Savoye\ LET\ CC. Savoye\ LET\ CC. ArtPen Handwritten)
 (Sawasdee Sawasdee SansSerif)
 (Sazanami\ Gothic Sazanami\ Gothic SansSerif)
 (Sazanami\ Mincho Sazanami\ Mincho)
 (Schwaben\ Alt Schwaben\ Alt Bold Condensed Gothic Medieval)
 (Seattle\ Avenue Seattle\ Avenue Bold Oblique SansSerif Pen Handwritten)
+(Seravek Seravek SansSerif)
+(Seravek\ ExtraLight Seravek\ Extra SansSerif)
 (Sertig Sertig Light Condensed SansSerif)
+(SF\ NS\ Display SF\ NS\ Display SansSerif)
+(SF\ NS\ Text SF\ NS\ Text SansSerif)
+(Shree\ Devanagari\ 714 Shree\ Devanagari\ 714 SansSerif)
 (Shruti Shruti SansSerif)
+(SignPainter-HouseScript SignPainter-HouseScript Marker Handwritten Italic)
 (Silom Silom Bold Typewriter Proportional SansSerif)
 (SimHei SimHei Mono SansSerif)
 (SimSun SimSun Mono)
+(Sinhala\ MN Sinhala\ MN)
+(Sinhala\ Sangam\ MN Sinhala\ Sangam\ MN SansSerif)
 (Skia Skia SansSerif)
+(Snell\ Roundhand Snell\ Roundhand ArtPen Handwritten Italic)
+(Songti\ SC Songti\ SC)
+(Songti\ TC Songti\ TC)
+(Source\ Han\ Sans\ SC Source\ Han\ Sans\ SC)
 (STFangsong STFangsong)
 (STHeiti STHeiti SansSerif)
 (Stix Stix)
 (Stix\ Math Stix\ Math)
 (STKaiti STKaiti)
 (STSong STSong)
+(Sukhumvit\ Set Sukhumvit\ Set SansSerif)
+(Superclarendon Superclarendon)
 (Sylfaen Sylfaen)
 (Symbol Symbol)
 (Tabaquera Tabaquera Black Outline)
@@ -348,7 +469,11 @@
 (TakaoMincho TakaoMincho)
 (TakaoPGothic TakaoPGothic SansSerif)
 (TakaoPMincho TakaoPMincho)
+(Tamil\ MN Tamil\ MN)
+(Tamil\ Sangam\ MN Tamil\ Sangam\ MN SansSerif)
 (Tangerine Tangerine Italic ArtPen Calligraphic)
+(Telugu\ MN Telugu\ MN)
+(Telugu\ Sangam\ MN Telugu\ Sangam\ MN SansSerif)
 (TeX\ AMS\ Blackboard\ Bold Bbb Outline)
 (TeX\ Bard bard Ancient)
 (TeX\ Blackboard\ Bold Bbb* Outline)
@@ -373,6 +498,7 @@
 (TeX\ Greek\ 6\ CBC greek6cbc Ancient)
 (TeX\ Gyre\ Adventor TeX\ Gyre\ Adventor SansSerif)
 (TeX\ Gyre\ Bonum TeX\ Gyre\ Bonum)
+(TeX\ Gyre\ Bonum\ Math TeX\ Gyre\ Bonum\ Math)
 (TeX\ Gyre\ Chorus TeX\ Gyre\ Chorus Italic Calligraphic)
 (TeX\ Gyre\ Cursor TeX\ Gyre\ Cursor Mono)
 (TeX\ Gyre\ Heros TeX\ Gyre\ Heros SansSerif)
@@ -380,6 +506,7 @@
 (TeX\ Gyre\ Pagella TeX\ Gyre\ Pagella)
 (TeX\ Gyre\ Pagella\ Math TeX\ Gyre\ Pagella\ Math)
 (TeX\ Gyre\ Schola TeX\ Gyre\ Schola)
+(TeX\ Gyre\ Schola\ Math TeX\ Gyre\ Schola\ Math)
 (TeX\ Gyre\ Termes TeX\ Gyre\ Termes)
 (TeX\ Gyre\ Termes\ Math TeX\ Gyre\ Termes\ Math)
 (TeX\ Hershey hershey)
@@ -426,9 +553,12 @@
 (Tlwg\ Typo Tlwg Mono)
 (TlwgMono Tlwg Mono)
 (TlwgTypewriter Tlwg Mono)
+(Trattatello Trattatello Retro)
 (Trebuchet\ MS Trebuchet\ MS SansSerif)
 (TriangleETcircle\ Shadow TriangleETcircle\ Shadow Outline)
 (TriangleETcircle\ Shadowed TriangleETcircle\ Shadowed Outline)
+(Tsukushi\ A\ Round\ Gothic Tsukushi\ A\ Round\ Gothic SansSerif)
+(Tsukushi\ B\ Round\ Gothic Tsukushi\ B\ Round\ Gothic)
 (Tt-Kp Tt-Kp Mono SansSerif)
 (Tuffy Tuffy SansSerif)
 (Tunga Tunga SansSerif)
@@ -450,10 +580,13 @@
 (Vipond\ Octic Vipond\ Octic Black SansSerif Miscellaneous)
 (Vrinda Vrinda SansSerif)
 (Waree Waree SansSerif)
+(Waseem Waseem)
+(Wawati\ SC Wawati\ SC SansSerif Marker Handwritten)
+(Wawati\ TC Wawati\ TC SansSerif Marker Handwritten)
 (Webdings Webdings)
-(WeblySleek\ UI\ Light WeblySleek\ UI SansSerif)
-(WeblySleek\ UI\ Semibold WeblySleek\ UI\ SemiBold Bold SansSerif)
-(WeblySleek\ UI\ Semilight WeblySleek\ UI\ Semilight SansSerif)
+(WeblySleek\ UI WeblySleek\ UI SansSerif)
+(Weibei\ SC Weibei\ SC Bold)
+(Weibei\ TC Weibei\ TC Bold)
 (WenQuanYi\ Micro\ Hei WenQuanYi\ Micro\ Hei)
 (WenQuanYi\ Micro\ Hei\ Mono WenQuanYi\ Micro\ Hei Mono)
 (WenQuanYi\ Zen\ Hei WenQuanYi\ Zen\ Hei SansSerif)
@@ -461,12 +594,19 @@
 (Wingdings\ 2 Wingdings\ 2)
 (Wingdings\ 3 Wingdings\ 3)
 (Wolgast\ Two Wolgast\ Two Italic ArtPen Attached Handwritten)
-(Wolgast\ Two\ Bold Wolgast\ Two Bold Oblique ArtPen Attached Handwritten)
+(Xingkai\ SC Xingkai\ SC ArtPen Handwritten)
 (Yiggivoo\ Unicode Yiggivoo\ Unicode Bold SansSerif)
 (Yiggivoo\ Unicode\  Yiggivoo\ Unicode Italic SansSerif)
 (Yiggivoo\ Unicode\ 3D Yiggivoo\ Unicode\ 3D Outline)
 (Yokawerad Yokawerad Black Wide)
 (YouYuan YouYuan Mono)
+(Yuanti\ SC Yuanti\ SC SansSerif)
+(Yuanti\ TC Yuanti\ TC SansSerif)
+(YuGothic YuGothic SansSerif)
+(YuMincho YuMincho)
+(YuMincho\ +36p\ Kana YuMincho\ +36p\ Kana)
+(Yuppy\ SC Yuppy\ SC SansSerif)
+(Yuppy\ TC Yuppy\ TC SansSerif)
 (Zantroke Zantroke Black)
 (Zapf\ Dingbats Zapf\ Dingbats)
 (Zapfino Zapfino Italic ArtPen Attached Calligraphic)
