@@ -1,4 +1,4 @@
-<TeXmacs|1.99.4>
+<TeXmacs|1.99.5>
 
 <style|<tuple|source|std>>
 
@@ -159,6 +159,8 @@
 
   <assign|english|<macro|body|<with|language|english|<arg|body>>>>
 
+  <assign|esperanto|<macro|body|<with|language|esperanto|<arg|body>>>>
+
   <assign|finnish|<macro|body|<with|language|finnish|<arg|body>>>>
 
   <assign|french|<macro|body|<with|language|french|<arg|body>>>>
@@ -259,6 +261,12 @@
     </surround>
   </macro>>
 
+  <assign|indivisible|<\macro|body>
+    <\surround|<no-break-start>|<no-break-end><right-flush>>
+      <arg|body>
+    </surround>
+  </macro>>
+
   \;
 
   <assign|center|<macro|body|<with|par-mode|center|<arg|body>>>>
@@ -317,6 +325,8 @@
 
   <assign|vphantom|<macro|body|<hresize|<phantom|<arg|body>>|0em|0em>>>
 
+  <assign|concealed|<macro|body|>>
+
   <\active*>
     <\src-comment>
       Adjusting the sizes of boxes.
