@@ -111,6 +111,8 @@
   (nasympasymp "{\\not\\asymp\\!\\!\\!\\!\\!\\!-}")
   (simsim "{\\approx\\!\\!\\!\\!\\!\\!-}")
   (nsimsim "{\\not\\approx\\!\\!\\!\\!\\!\\!-}")
+  (triplesim "{\\approx\\!\\!\\!\\!\\!\\!\\sim}")
+  (ntriplesim "{\\not\\approx\\!\\!\\!\\!\\!\\!\\sim}")
   (precprec "\\prec\\!\\!\\!\\prec")
   (precpreceq "\\preceq\\!\\!\\!\\preceq")
   (precprecprec "\\prec\\!\\!\\!\\prec\\!\\!\\!\\prec")
@@ -152,6 +154,7 @@
   (Exists "\\exists")
   (bigintwl "\\int")
   (bigointwl "\\oint")
+  (of ":")
   (point ".")
   (cdummy "\\cdot")
   (comma "{,}")
@@ -193,6 +196,7 @@
   (minusassign "-\\!\\!=")
   (timesassign "\times\\!\\!=")
   (overassign "/\\!\\!=")
+  (backassign "=:")
   (lflux "\\ll")
   (gflux "\\gg")
   (colons "\\,:\\,")
@@ -213,7 +217,6 @@
   ;; Nullary macros
   (tmunsc "\\_")
   (emdash "---")
-  (tmhrule "\\noindent\\rule[0.3\\baselineskip]{\\textwidth}{0.4pt}")
   (tmat "\\symbol{\"40}")
   (tmbsl "\\ensuremath{\\backslash}")
   (tmdummy "$\\mbox{}$")
