@@ -191,8 +191,9 @@
           ((cannot-write? name "Save file")
            (noop))
           ((and (url-test? name "fr")
-                (> (url-last-modified name)
-                   (buffer-last-save name)))
+		(and-with mod-t (url-last-modified name)
+		  (and-with save-t (buffer-last-save name)
+		    (> mod-t save-t))))
            (user-confirm "The file has changed on disk. Really save?" #f
              (lambda (answ)
                (when answ
@@ -536,21 +537,50 @@
 ;; Printing buffers
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(tm-define (print-buffer)
-  (:synopsis "Print the current buffer")
-  (print))
-
 (tm-define (interactive-page-setup)
   (:synopsis "Specify the page setup")
   (:interactive #t)
   (set-message "Not yet implemented" "Printer setup"))
 
+(tm-define (direct-print-buffer)
+  (:synopsis "Print the current buffer")
+  (print))
+
 (tm-define (interactive-print-buffer)
   (:synopsis "Print the current buffer")
   (:interactive #t)
   (print-to-file "$TEXMACS_HOME_PATH/system/tmp/tmpprint.ps")
   (interactive-print '() "$TEXMACS_HOME_PATH/system/tmp/tmpprint.ps"))
 
+(tm-define (print-buffer)
+  (:synopsis "Print the current buffer")
+  (:interactive (use-print-dialog?))
+  (if (use-print-dialog?)
+      (interactive-print-buffer)
+      (direct-print-buffer)))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Important files to which the buffer is linked (e.g. bibliographies)
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(define (linked-files-inside t)
+  (cond ((tree-atomic? t) (list))
+        ((tree-is? t 'document)
+         (append-map linked-files-inside (tree-children t)))
+        ((tree-in? t '(with with-bib))
+         (linked-files-inside (tm-ref t :last)))
+        ((or (tree-func? t 'bibliography 4)
+	     (tree-func? t 'bibliography* 5))
+         (with name (tm->stree (tm-ref t 2))
+           (if (or (== name "") (nstring? name)) (list)
+               (with s (if (string-ends? name ".bib") name
+                           (string-append name ".bib"))
+                 (list (url-relative (current-buffer) s))))))
+        (else (list))))
+
+(tm-define (linked-file-list)
+  (linked-files-inside (buffer-tree)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Deprecated functionality
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
