@@ -47,10 +47,15 @@
       (-> "Font" (link text-font-menu)))
   ("Paragraph" (open-paragraph-format))
   ("Page" (open-page-format))
+  (when (inside? 'table)
+    ("Cell" (open-cell-properties))
+    ("Table" (open-table-properties)))
   ---
   (-> "Whitespace" (link space-menu))
   (-> "Indentation" (link indentation-menu))
   (-> "Break" (link break-menu))
+  (when (and (selection-active-small?) (tm-atomic? (selection-tree)))
+    ("Hyphenate as" (interactive hyphenate-selection-as)))
   ---
   (-> "Color"
       (if (== (get-preference "experimental alpha") "on")
@@ -58,8 +63,12 @@
           ---)
       (link color-menu))
   (-> "Adjust" (link adjust-menu))
+  (-> "Transform" (link linear-transform-menu))
   (-> "Specific" (link specific-menu))
-  (-> "Special" (link format-special-menu)))
+  (-> "Special" (link format-special-menu))
+  (-> "Font effects" (link text-font-effects-menu))
+  (assuming (== (get-preference "bitmap effects") "on")
+    (-> "Graphical effects" (link text-effects-menu))))
 
 (menu-bind text-format-menu
   (if (use-menus?)
@@ -83,7 +92,7 @@
   (when (inside? 'letter-header)
         ("Address" (make-header 'address))
         ("Date" (make-header 'letter-date))
-        ("Today" (begin (make-header 'letter-date) (make-arity 'date 0)))
+        ("Today" (begin (make-header 'letter-date) (make 'date 0)))
         ("Destination" (make-header 'destination)))
   ---
   (when (not (inside? 'letter-header))
@@ -185,6 +194,9 @@
   (-> "Inline code"
       ("C++" (make 'cpp))
       ("Mathemagix" (make 'mmx))
+      ("Python" (make 'python))
+      ("R" (make 'r))
+      ("Scala" (make 'scala))
       ("Scheme" (make 'scm))
       ("Shell" (make 'shell))
       ("Scilab" (make 'scilab))
@@ -192,6 +204,9 @@
   (-> "Block of code"
       ("C++" (make 'cpp-code))
       ("Mathemagix" (make 'mmx-code))
+      ("Python" (make 'python-code))
+      ("R" (make 'r-code))
+      ("Scala" (make 'scala-code))
       ("Scheme" (make 'scm-code))
       ("Shell" (make 'shell-code))
       ("Scilab" (make 'scilab-code))
@@ -208,6 +223,7 @@
     ;;("Balloon" (make-balloon))
     ---
     ("Floating object" (make-insertion "float"))
+    ("Floating phantom" (insert '(phantom-float "float" "hf")))
     ("Floating figure" (begin (make-insertion "float") (make 'big-figure)))
     ("Floating table" (begin (make-insertion "float")
                              (insert-go-to '(big-table "" "") '(0 0))
@@ -230,31 +246,40 @@
 (tm-define (marginal-note-context? t)
   (tree-is? t 'marginal-note))
 
-(tm-menu (focus-position-float-menu t)
+(tm-menu (focus-float-menu t)
   (:require (marginal-note-context? t))
   ---
   (link position-marginal-note-menu)
   ---)
 
-(menu-bind position-float-menu
+(menu-bind float-menu
   ("Top" (toggle-insertion-positioning "t"))
   ("Here" (toggle-insertion-positioning "h"))
   ("Bottom" (toggle-insertion-positioning "b"))
   ("Other pages" (toggle-insertion-positioning-not "f")))
 
-(tm-define (float-context? t)
-  (cond ((tree-is? t 'float) #t)
-        ((tree-in? t '(big-figure big-figure*
-                       big-table big-table*
-                       algorithm algorithm*
-                       document concat))
-         (and (tree-up t) (float-context? (tree-up t))))
-        (else #f)))
-
-(tm-menu (focus-position-float-menu t)
+(tm-menu (focus-float-menu t)
   (:require (float-context? t))
-  (-> "Allowed positions"
-      (link position-float-menu)))
+  (-> "Allowed positions" (link float-menu))
+  (if (cursor-at-anchor?)
+      ("Go to float" (go-to-float)))
+  (if (not (cursor-at-anchor?))
+      ("Go to anchor" (go-to-anchor))))
+
+(tm-menu (focus-float-menu t)
+  (:require (phantom-float-context? t))
+  (-> "Allowed positions" (link float-menu)))
+
+(tm-menu (focus-float-menu t)
+  (:require (floatable-context? t))
+  ("Make floating" (turn-floating t)))
+
+(tm-menu (focus-float-menu t)
+  (:require (tree-is? t 'footnote))
+  (if (cursor-at-anchor?)
+      ("Go to footnote" (go-to-float)))
+  (if (not (cursor-at-anchor?))
+      ("Go to anchor" (go-to-anchor))))
 
 (menu-bind position-balloon-menu
   (group "Horizontal alignment")
@@ -271,7 +296,7 @@
   ("Inner top" (set-balloon-valign "top"))
   ("Outer top" (set-balloon-valign "Top")))
 
-(tm-menu (focus-position-float-menu t)
+(tm-menu (focus-float-menu t)
   (:require (balloon-context? t))
   ---
   (link position-balloon-menu)
@@ -367,7 +392,8 @@
   ("Compact" (make-tmlist 'description-compact))
   ("Aligned" (make-tmlist 'description-aligned))
   ("Dashes" (make-tmlist 'description-dash))
-  ("Long" (make-tmlist 'description-long)))
+  ("Long" (make-tmlist 'description-long))
+  ("Paragraphs" (make-tmlist 'description-paragraphs)))
 
 (menu-bind list-menu
   ("Itemize" (make-tmlist 'itemize))
@@ -389,30 +415,34 @@
   ("Compact" (make-tmlist 'description-compact))
   ("Aligned" (make-tmlist 'description-aligned))
   ("Dashes" (make-tmlist 'description-dash))
-  ("Long" (make-tmlist 'description-long)))
+  ("Long" (make-tmlist 'description-long))
+  ("Paragraphs" (make-tmlist 'description-paragraphs)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Automatically generated content
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (menu-bind automatic-menu
-  ("Table of contents" (make-aux "table-of-contents" "toc"))
+  ("Table of contents" (make-aux "table-of-contents" "toc-prefix" "toc"))
   (assuming (get-boolean-preference "gui:new bibliography dialogue")
     ("Bibliography" (interactive open-bibliography-inserter)))
   (assuming (not (get-boolean-preference "gui:new bibliography dialogue"))
-    ("Bibliography" (interactive make-bib)))
-  ("Index" (make-aux "the-index" "idx"))
-  ("Glossary" (make-aux "the-glossary" "gly"))
-  ;;("List of figures" (make-aux* "the-glossary*" "figure" "List of figures"))
-  ;;("List of tables" (make-aux* "the-glossary*" "table" "List of tables"))
-  ("List of figures" (make-aux "list-of-figures" "figure"))
-  ("List of tables" (make-aux "list-of-tables" "table")))
+    (if (with-database-tool?)
+        ("Bibliography" (make-database-bib)))
+    (if (not (with-database-tool?))
+        ("Bibliography" (choose-file make-bib "Bibliography file" "BibTeX"))))
+  ("Index" (make-aux "the-index" "index-prefix" "idx"))
+  ("Glossary" (make-aux "the-glossary" "glossary-prefix" "gly"))
+  ;;("List of figures" (make-aux* "the-glossary*" "figure-list-prefix" "figure" "List of figures"))
+  ;;("List of tables" (make-aux* "the-glossary*" "table-list-prefix" "table" "List of tables"))
+  ("List of figures" (make-aux "list-of-figures" "figure-list-prefix" "figure"))
+  ("List of tables" (make-aux "list-of-tables" "table-list-prefix" "table")))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;; Style dependent menus
+;; Text menus for inserting block content
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(menu-bind text-menu
+(menu-bind text-block-menu
   (if (and (style-has? "header-title-dtd")
            (not (style-has? "header-letter-dtd"))
            (not (style-has? "header-exam-dtd")))
@@ -441,26 +471,74 @@
       ---
       (-> "Itemize" (link itemize-menu))
       (-> "Enumerate" (link enumerate-menu))
-      (-> "Description" (link description-menu)))
-  ---
+      (-> "Description" (link description-menu))))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Text menus for inserting inline content
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(menu-bind text-inline-menu
   (if (style-has? "std-markup-dtd")
       (-> "Content tag" (link content-tag-menu))
       (-> "Size tag" (link size-tag-menu)))
   (-> "Presentation tag" (link presentation-tag-menu))
   (if (style-has? "std-markup-dtd")
       (-> "Language" (link text-language-menu)))
-  (-> "Scripts" (link local-supported-scripts-menu))
+  (-> "Scripts" (link local-supported-scripts-menu)))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Style dependent menus
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(menu-bind text-menu
+  (link text-block-menu)
   ---
-  (-> "Mathematics" (link insert-math-menu))
-  (-> "Table" (link insert-table-menu))
-  (-> "Image" (link insert-image-menu))
-  (-> "Link" (link insert-link-menu))
-  (if (detailed-menus?)
-      (if (style-has? "std-fold-dtd")
-          (-> "Fold" (link insert-fold-menu)))
-      (-> "Animation" (link insert-animation-menu)))
-  (if (and (style-has? "session-dtd") (detailed-menus?))
-      (-> "Session" (link insert-session-menu))))
+  (link text-inline-menu)
+  ---
+  (link texmacs-insert-menu))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Icons for inserting block markup
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(menu-bind text-block-icons
+  (if (style-has? "header-letter-dtd")
+      (=> (balloon (icon "tm_title.xpm") "Make a letter environment")
+          (link letter-header-menu)))
+  (if (style-has? "header-exam-dtd")
+      (=> (balloon (icon "tm_title.xpm") "Enter title information")
+          (link exam-header-menu)))
+  (if (style-has? "book-style")
+      (=> (balloon (icon "tm_chapter.xpm") "Start a new chapter")
+          (link chapter-menu)))
+  (if (and (style-has? "section-base-dtd")
+           (not (style-has? "header-exam-dtd")))
+      (=> (balloon (icon "tm_section.xpm") "Start a new section")
+          (link section-menu)))
+  (if (or (style-has? "env-theorem-dtd")
+          (style-has? "header-exam-dtd"))
+      (=> (balloon (icon "tm_theorem.xpm") "Insert an enunciation")
+          (link enunciation-menu)))
+  (if (style-has? "std-markup-dtd")
+      (=> (balloon (icon "tm_prominent.xpm") "Insert a prominent piece of text")
+          (link prominent-menu)))
+  (if (style-has? "std-markup-dtd")
+      (=> (balloon (icon "tm_program.xpm") "Insert a computer program")
+          (link code-menu)))
+  (if (style-has? "std-list-dtd")
+      (=> (balloon (icon "tm_list.xpm") "Insert a list")
+          (link list-menu)))
+  (if (and (style-has? "env-float-dtd") (detailed-menus?))
+      ;;((balloon (icon "tm_footnote.xpm") "Insert a footnote") ())
+      ;;((balloon (icon "tm_margin.xpm") "Insert a marginal note") ())
+      ;;((balloon (icon "tm_floating.xpm") "Insert a floating object") ())
+      ;;((balloon (icon "tm_multicol.xpm") "Start multicolumn context") ())
+      (=> (balloon (icon "tm_pageins.xpm") "Insert a note or a floating object")
+          (link note-menu)))
+  (if (style-has? "section-base-dtd")
+      (=> (balloon (icon "tm_index.xpm")
+                   "Insert automatically generated content")
+          (link automatic-menu))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Icons for modifying text properties
@@ -511,6 +589,9 @@
   (=> (balloon (icon "tm_color.xpm") "Select a foreground color")
       (link color-menu)))
 
+(menu-bind text-inline-icons
+  (link text-format-icons))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Icons for text mode
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -518,48 +599,15 @@
 (menu-bind text-icons
   ;;("Goedenmiddag" (display* "Hi there\n"))
   ;;(mini #t (input (display* answer "\n") "string" '("Hello" "Bonjour") "0.5w"))
-  (if (style-has? "header-letter-dtd")
-      (=> (balloon (icon "tm_title.xpm") "Make a letter environment")
-          (link letter-header-menu)))
-  (if (style-has? "header-exam-dtd")
-      (=> (balloon (icon "tm_title.xpm") "Enter title information")
-          (link exam-header-menu)))
-  (if (style-has? "book-style")
-      (=> (balloon (icon "tm_chapter.xpm") "Start a new chapter")
-          (link chapter-menu)))
-  (if (and (style-has? "section-base-dtd")
-           (not (style-has? "header-exam-dtd")))
-      (=> (balloon (icon "tm_section.xpm") "Start a new section")
-          (link section-menu)))
-  (if (or (style-has? "env-theorem-dtd")
-          (style-has? "header-exam-dtd"))
-      (=> (balloon (icon "tm_theorem.xpm") "Insert an enunciation")
-          (link enunciation-menu)))
-  (if (style-has? "std-markup-dtd")
-      (=> (balloon (icon "tm_prominent.xpm") "Insert a prominent piece of text")
-          (link prominent-menu)))
-  (if (style-has? "std-markup-dtd")
-      (=> (balloon (icon "tm_program.xpm") "Insert a computer program")
-          (link code-menu)))
-  (if (style-has? "std-list-dtd")
-      (=> (balloon (icon "tm_list.xpm") "Insert a list")
-          (link list-menu)))
-  (if (and (style-has? "env-float-dtd") (detailed-menus?))
-      ;;((balloon (icon "tm_footnote.xpm") "Insert a footnote") ())
-      ;;((balloon (icon "tm_margin.xpm") "Insert a marginal note") ())
-      ;;((balloon (icon "tm_floating.xpm") "Insert a floating object") ())
-      ;;((balloon (icon "tm_multicol.xpm") "Start multicolumn context") ())
-      (=> (balloon (icon "tm_pageins.xpm") "Insert a note or a floating object")
-          (link note-menu)))
-  (if (style-has? "section-base-dtd")
-      (=> (balloon (icon "tm_index.xpm")
-                   "Insert automatically generated content")
-          (link automatic-menu)))
+  (link text-block-icons)
   (if (style-has? "std-markup-dtd")
       /)
-  (link text-format-icons)
+  (link text-inline-icons)
   (if (in-manual?) (link tmdoc-icons))
-  (link texmacs-insert-icons))
+  (link texmacs-insert-icons)
+  (if (and (in-presentation?) (not (visible-icon-bar? 0)))
+    /
+    (link dynamic-icons)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Focus menus for entering title information
@@ -592,7 +640,7 @@
   ("Author" (make-doc-data-element 'doc-author))
   ("Date" (make-doc-data-element 'doc-date))
   ("Today"
-   (begin (make-doc-data-element 'doc-date) (make-arity 'date 0)))
+   (begin (make-doc-data-element 'doc-date) (make 'date 0)))
   ("Miscellanous" (make-doc-data-element 'doc-misc))
   ("Note" (make-doc-data-element 'doc-note))
   ("TeXmacs notice" (begin (make-doc-data-element 'doc-note)
@@ -766,6 +814,10 @@
     (=> (eval (tm/section-get-title-string t))
         (link focus-section-menu))))
 
+(tm-define (child-proposals t i)
+  (:require (and (tree-in? t '(bibliography bibliography*)) (== i 1)))
+  (bib-standard-styles))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Focus menu for lists
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -839,19 +891,40 @@
 ;; Focus menus for floating objects
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(tm-menu (focus-position-float-icons t)
+(tm-menu (focus-float-icons t)
   (:require (marginal-note-context? t))
   (=> (balloon (icon "tm_position_float.xpm")
                "Position of marginal note")
       (link position-marginal-note-menu)))
 
-(tm-menu (focus-position-float-icons t)
+(tm-menu (focus-float-icons t)
   (:require (float-context? t))
   (=> (balloon (icon "tm_position_float.xpm")
                "Allowed positions of floating object")
-      (link position-float-menu)))
+      (link float-menu))
+  ((balloon (icon "tm_anchor.xpm")
+            "Go to anchor or float")
+   (cursor-toggle-anchor)))
 
-(tm-menu (focus-position-float-icons t)
+(tm-menu (focus-float-icons t)
+  (:require (phantom-float-context? t))
+  (=> (balloon (icon "tm_position_float.xpm")
+               "Allowed positions of floating object")
+      (link float-menu)))
+
+(tm-menu (focus-float-icons t)
+  (:require (floatable-context? t))
+  ((balloon (icon "tm_position_float.xpm")
+            "Let the environment float")
+   (turn-floating (tree-innermost floatable-context?))))
+
+(tm-menu (focus-float-icons t)
+  (:require (tree-is? t 'footnote))
+  ((balloon (icon "tm_anchor.xpm")
+            "Go to anchor or footnote")
+   (cursor-toggle-anchor)))
+
+(tm-menu (focus-float-icons t)
   (:require (balloon-context? t))
   (=> (balloon (icon "tm_position_float.xpm")
                "Alignment of balloon")
@@ -895,3 +968,18 @@
           (frame-titled? (focus-tree)))
    (frame-toggle-title t))
   (dynamic (former t)))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Renaming automatically generated sections
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(tm-menu (focus-toggle-menu t)
+  (:require (automatic-section-context? t))
+  (dynamic (former t))
+  ("Rename" (interactive automatic-section-rename)))
+
+(tm-menu (focus-toggle-icons t)
+  (:require (automatic-section-context? t))
+  (dynamic (former t))
+  ((balloon (icon "tm_small_textual.xpm") "Rename section")
+   (interactive automatic-section-rename)))
